@@ -1,12 +1,10 @@
-import asyncio
 import aiohttp
-import threading
 
 from typing import Tuple, Dict
 from fastapi import Response
 
 
-async def proxy_response(response: aiohttp.ClientResponse):
+async def proxy_response(response: aiohttp.ClientResponse) -> Response:
     content = await response.text()
     return Response(
         content=content,
